@@ -67,7 +67,7 @@ $lang = array_merge($lang, array(
 	'DEFAULT_LANGUAGE'		=> 'Idioma por defecto',
 	'DEFAULT_STYLE'			=> 'Estilo por defecto',
 	'DISABLE_BOARD'			=> 'Deshabilitar Sitio',
-	'DISABLE_BOARD_EXPLAIN'		=> 'Esto hará al Sitio inaccesible a los usuarios. Si quiere, también puede introducir un breve mensaje (255 caracteres) para mostrar.',
+	'DISABLE_BOARD_EXPLAIN'		=> 'Esto hará al Sitio inaccesible a los usuarios que no son Administradores ni Moderadores. Si quiere, también puede introducir un breve mensaje (255 caracteres) para mostrar.',
 	'OVERRIDE_STYLE'		=> 'Sustituir estilo del usuario',
 	'OVERRIDE_STYLE_EXPLAIN'	=> 'Reemplaza el estilo del usuario por el estilo por defecto.',
 	'SITE_DESC'			=> 'Descripción del Sitio',
@@ -118,16 +118,16 @@ $lang = array_merge($lang, array(
 
 	'ALLOW_AVATARS'			=> 'Habilitar avatares',
 	'ALLOW_AVATARS_EXPLAIN'		=> 'Permitir el uso general de avatares;<br />Si deshabilita los avatares en general o los avatares en algún modo, los avatares deshabilitados no serán mostrados más en el foro, pero los usuarios aún podrán descargar sus propios avatares a través del Panel de Control de Usuario.',
-    	'ALLOW_LOCAL'			=> 'Habilitar galería de avatares',
+    'ALLOW_LOCAL'			=> 'Habilitar galería de avatares',
 	'ALLOW_REMOTE'			=> 'Habilitar avatares remotos',
 	'ALLOW_REMOTE_EXPLAIN'		=> 'Avatares enlazados de otro sitio web',
 	'ALLOW_REMOTE_UPLOAD'		=> 'Permitir subida remota de avatares',
 	'ALLOW_REMOTE_UPLOAD_EXPLAIN'	=> 'Permitir subida de avatares desde otra web.',
 	'ALLOW_UPLOAD'			=> 'Habilitar la subida de avatares',
 	'AVATAR_GALLERY_PATH'		=> 'Ruta de galería de avatares',
-	'AVATAR_GALLERY_PATH_EXPLAIN'	=> 'Ruta en su directorio raíz para imagenes precargadas, ej. <samp>images/avatars/gallery</samp>',
+	'AVATAR_GALLERY_PATH_EXPLAIN'	=> 'Ruta en su directorio raíz para imágenes precargadas, ej. <samp>images/avatars/gallery</samp>',
 	'AVATAR_STORAGE_PATH'		=> 'Ruta en la que se guardarán los avatares',
-	'AVATAR_STORAGE_PATH_EXPLAIN'	=> 'Ruta en su directorio raíz, ej. <samp>images/avatars/upload</samp>',
+	'AVATAR_STORAGE_PATH_EXPLAIN'	=> 'Ruta en su directorio raíz, ej. <samp>images/avatars/upload</samp><br />La subida de Avatar <strong>no estará disponible</strong> si no se puede escribir en esa ruta.',
 	'MAX_AVATAR_SIZE'		=> 'Dimensiones máximas del avatar',
 	'MAX_AVATAR_SIZE_EXPLAIN'	=> '(Ancho x Alto en pixels)',
 	'MAX_FILESIZE'			=> 'Tamaño máximo del avatar',
