@@ -289,7 +289,7 @@ $lang = array_merge($lang, array(
 	'MOVE_DELETED_MESSAGES_TO'		=> 'Mover mensajes del directorio eliminado a',
 	'MOVE_DOWN'						=> 'Bajar',
 	'MOVE_MARKED_TO_FOLDER'			=> 'Mover marcados a %s',
-	'MOVE_PM_ERROR'					=> 'Ha ocurrido un error mientras movía los mensajes al nuevo directorio, sólo %1d de %2d mensajes fueron movidos.',
+	'MOVE_PM_ERROR'					=> 'Ha ocurrido un error mientras movía los mensajes al nuevo directorio, sólo %1$d de %2$d mensajes fueron movidos.',
 	'MOVE_TO_FOLDER'				=> 'Mover a directorio',
 	'MOVE_UP'						=> 'Subir',
 	'NEW_EMAIL_CONFIRM_EMPTY'		=> 'Usted no ha introducido la confirmación de dirección de correo.',
